==> qtbox-1.1.5.tar.gz: qtbox-1.1.5/README.md <==
# Qt Box ([中文](https://zhuanlan.zhihu.com/p/606612591))
<p dir="auto">
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/Qt Box-Open Source-green.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://static.pepy.tech/personalized-badge/qtbox?period=total&units=international_system&left_color=grey&right_color=blue&left_text=Downloads" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/For-PyQt and PySide-dark.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/Language-Python-purple.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/Author-Louis Ren-orange.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/License-GPL v3-red.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/With-QSS Editor-brown.svg" />
    </a>
</p>

Qt Box contains many common and useful PyQt & PySide widget demos, which may save your time during development.

## Installation
```markdown
pip install qtbox
```

## How to use
Open a command window and use command `qtbox` to show Qt Box GUI.
<img src="https://img-blog.csdnimg.cn/5aa9084276a44804a3a49eac54f7e7c3.png" width="600">

Right-click on a widget shown in the Style tab or Function tab, then you can view or download the code.
<img src="https://img-blog.csdnimg.cn/501983f31ebe4cbfbdb9d95dbed96d53.png" width="600">

When viewing the code, you can click on the switch button to show PyQt or PySide code.
<img src="https://img-blog.csdnimg.cn/ab1828e5b1024ece81e4388ff96ac48a.png" width="600">

On the main window, click on the switch button to change the window theme.
<img src="https://img-blog.csdnimg.cn/a0a84cf9b50b4f92a52f0f65e1664196.png" width="600">

Click on the edit button or type `qtbox-qss` in the command window to open QSS Editor.
<img src="https://img-blog.csdnimg.cn/7289f04c21824d0986f6adcb96a4be2e.png" width="600">

## For C++ Qt users
If you don't have a Python environment, download QtBox.zip which includes `qtbox.exe` executable file.
<img src="https://img-blog.csdnimg.cn/edb04ba49468484696efec78f07bb740.jpeg" width="300">

## Support author
Support author to make this project better. Thanks a lot. :)
- [PayPal](https://www.paypal.com/paypalme/louisren666)
- [WeChat or AliPay](https://pic4.zhimg.com/v2-6cad70f5aeeb9cc1a8a95c66b36a7ab7_r.jpg)


## Other links
- [Github](https://github.com/la-vie-est-belle/qtbox)
- [CSDN](https://blog.csdn.net/La_vie_est_belle/article/details/129037040)
- [Bilibili](https://space.bilibili.com/414891732)
- [知乎](https://zhuanlan.zhihu.com/p/606612591)
- [PyPi](https://pypi.org/project/qtbox/)

==> qtbox-1.2.0.tar.gz: qtbox-1.2.0/README.md <==
# Qt Box ([中文](https://zhuanlan.zhihu.com/p/606612591))
<p dir="auto">
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/Qt Box-Open Source-green.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://static.pepy.tech/personalized-badge/qtbox?period=total&units=international_system&left_color=grey&right_color=blue&left_text=Downloads" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/For-PyQt and PySide-dark.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/Language-Python-purple.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/Author-Louis Ren-orange.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/License-GPL v3-red.svg" />
    </a>
    <a href="javascript:;">
        <img src="https://img.shields.io/badge/With-QSS Editor-brown.svg" />
    </a>
</p>

Qt Box contains many common and useful PyQt & PySide widget demos, which may save your time during development.

## Installation
```markdown
pip install qtbox
```

## How to use
Open a command window and use command `qtbox` to show Qt Box GUI.
<img src="https://img-blog.csdnimg.cn/5aa9084276a44804a3a49eac54f7e7c3.png" width="600">

Right-click on a widget shown in the Style tab or Function tab, then you can view or download the code.
<img src="https://img-blog.csdnimg.cn/501983f31ebe4cbfbdb9d95dbed96d53.png" width="600">

When viewing the code, you can click on the switch button to show PyQt, PySide or C++/Qt code.
<img src="https://img-blog.csdnimg.cn/ab1828e5b1024ece81e4388ff96ac48a.png" width="600">

On the main window, click on the switch button to change the window theme.
<img src="https://img-blog.csdnimg.cn/a0a84cf9b50b4f92a52f0f65e1664196.png" width="600">

Click on the edit button or type `qtbox-qss` in the command window to open QSS Editor.
<img src="https://img-blog.csdnimg.cn/7289f04c21824d0986f6adcb96a4be2e.png" width="600">

## For C++ Qt users
If you don't have a Python environment, download [QtBox.zip](https://la-vie-est-belle.github.io/qtbox/Qt%20Box.zip) which includes `qtbox.exe` executable file.
<img src="https://img-blog.csdnimg.cn/edb04ba49468484696efec78f07bb740.jpeg" width="300">

## Support author
Support author to make this project better. Thanks a lot. :)
- [PayPal](https://www.paypal.com/paypalme/louisren666)
- [WeChat or AliPay](https://pic4.zhimg.com/v2-6cad70f5aeeb9cc1a8a95c66b36a7ab7_r.jpg)

## Other links
- [Github](https://github.com/la-vie-est-belle/qtbox)
- [CSDN](https://blog.csdn.net/La_vie_est_belle/article/details/129037040)
- [Bilibili](https://space.bilibili.com/414891732)
- [知乎](https://zhuanlan.zhihu.com/p/606612591)
- [PyPi](https://pypi.org/project/qtbox/)
